@@ -1908,6 +1908,12 @@ evdev_pre_configure_model_quirks(struct evdev_device *device)
 		libevdev_enable_property(device->evdev,
 					 INPUT_PROP_BUTTONPAD);
 
+	/* Touchpad is a clickpad but INPUT_PROP_BUTTONPAD is not set, see
+	 * https://gitlab.freedesktop.org/libinput/libinput/issues/177 */
+	if (evdev_device_has_model_quirk(device, QUIRK_MODEL_LENOVO_T480S_TOUCHPAD))
+		libevdev_enable_property(device->evdev,
+					 INPUT_PROP_BUTTONPAD);
+
 	/* Touchpad claims to have 4 slots but only ever sends 2
 	 * https://bugs.freedesktop.org/show_bug.cgi?id=98100 */
 	if (evdev_device_has_model_quirk(device, QUIRK_MODEL_HP_ZBOOK_STUDIO_G3))
