@@ -26,12 +26,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void litest_mouse_setup(void)
-{
-	struct litest_device *d = litest_create_device(LITEST_MOUSE_LOW_DPI);
-	litest_set_current_device(d);
-}
-
 static struct input_id input_id = {
 	.bustype = 0x3,
 	.vendor = 0x1,
@@ -58,11 +52,9 @@ static const char udev_rule[] =
 "\n"
 "LABEL=\"touchpad_end\"";
 
-struct litest_test_device litest_mouse_low_dpi_device = {
+TEST_DEVICE("low-dpi-mouse",
 	.type = LITEST_MOUSE_LOW_DPI,
 	.features = LITEST_RELATIVE | LITEST_BUTTON | LITEST_WHEEL,
-	.shortname = "low-dpi mouse",
-	.setup = litest_mouse_setup,
 	.interface = NULL,
 
 	.name = "Low DPI Mouse",
@@ -70,4 +62,4 @@ struct litest_test_device litest_mouse_low_dpi_device = {
 	.absinfo = NULL,
 	.events = events,
 	.udev_rule = udev_rule,
-};
+)
