@@ -32,28 +32,30 @@
 #define LITEST_AUTO_ASSIGN INT_MIN
 
 struct litest_test_device {
-       enum litest_device_type type;
-       enum litest_device_feature features;
-       const char *shortname;
-       void (*setup)(void); /* test fixture, used by check */
-       void (*teardown)(void); /* test fixture, used by check */
-       /**
+	struct list node; /* global test device list */
+
+	enum litest_device_type type;
+	enum litest_device_feature features;
+	const char *shortname;
+	void (*setup)(void); /* test fixture, used by check */
+	void (*teardown)(void); /* test fixture, used by check */
+	/**
 	* If create is non-NULL it will be called to initialize the device.
 	* For such devices, no overrides are possible. If create is NULL,
 	* the information in name, id, events, absinfo is used to
 	* create the device instead.
 	*/
-       void (*create)(struct litest_device *d);
+	void (*create)(struct litest_device *d);
 
-       /**
-	* The device name. Only used when create is NULL.
-	*/
-       const char *name;
-       /**
-	* The device id. Only used when create is NULL.
-	*/
-       const struct input_id *id;
-       /**
+	/**
+	 * The device name. Only used when create is NULL.
+	 */
+	const char *name;
+	/**
+	 * The device id. Only used when create is NULL.
+	 */
+	const struct input_id *id;
+	/**
 	* List of event type/code tuples, terminated with -1, e.g.
 	* EV_REL, REL_X, EV_KEY, BTN_LEFT, -1
 	* Special tuple is INPUT_PROP_MAX, <actual property> to set.
@@ -61,15 +63,16 @@ struct litest_test_device {
 	* Any EV_ABS codes in this list will be initialized with a default
 	* axis range.
 	*/
-       int *events;
-       /**
-	* List of abs codes to enable, with absinfo.value determining the
-	* code to set. List must be terminated with absinfo.value -1
-	*/
-       struct input_absinfo *absinfo;
-       struct litest_device_interface *interface;
+	int *events;
+	/**
+	 * List of abs codes to enable, with absinfo.value determining the
+	 * code to set. List must be terminated with absinfo.value -1
+	 */
+	struct input_absinfo *absinfo;
+	struct litest_device_interface *interface;
 
-       const char *udev_rule;
+	const char *udev_rule;
+	const char *quirk_file;
 };
 
 struct litest_device_interface {
